==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/ToolActionIconMenuDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionMenuBaseDescriptionMetadata } from "./ToolActionMenuBaseDescriptionMetadata";
import { ToolActionIconMenuDescription } from "./ToolActionIconMenuDescription";
/**
 * @hidden
 */
export let ToolActionIconMenuDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolActionIconMenuDescriptionMetadata extends Base {
        static b(a) {
            if (ToolActionIconMenuDescriptionMetadata.a == null) {
                ToolActionIconMenuDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolActionIconMenuDescriptionMetadata.c(ToolActionIconMenuDescriptionMetadata.a);
            }
            if (a.j(ToolActionIconMenuDescriptionMetadata.a)) {
                return;
            }
            a.y(ToolActionIconMenuDescriptionMetadata.a);
        }
        static c(a) {
            ToolActionMenuBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            ToolActionIconMenuDescriptionMetadata.b(a);
            a.aa("ToolActionIconMenu", () => new ToolActionIconMenuDescription());
            a.z("ToolActionIconMenu", ToolActionIconMenuDescriptionMetadata.a);
        }
    }
    ToolActionIconMenuDescriptionMetadata.$t = /*@__PURE__*/ markType(ToolActionIconMenuDescriptionMetadata, 'ToolActionIconMenuDescriptionMetadata');
    ToolActionIconMenuDescriptionMetadata.a = null;
    return ToolActionIconMenuDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/ToolActionIconMenuDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionMenuBaseDescriptionMetadata } from "./ToolActionMenuBaseDescriptionMetadata";
import { ToolActionIconMenuDescription } from "./ToolActionIconMenuDescription";
/**
 * @hidden
 */
export let ToolActionIconMenuDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolActionIconMenuDescriptionMetadata extends Base {
        static b(a) {
            if (ToolActionIconMenuDescriptionMetadata.a == null) {
                ToolActionIconMenuDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolActionIconMenuDescriptionMetadata.c(ToolActionIconMenuDescriptionMetadata.a);
            }
            if (a.k(ToolActionIconMenuDescriptionMetadata.a)) {
                return;
            }
            a.aa(ToolActionIconMenuDescriptionMetadata.a);
        }
        static c(a) {
            ToolActionMenuBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            ToolActionIconMenuDescriptionMetadata.b(a);
            a.ac("ToolActionIconMenu", () => new ToolActionIconMenuDescription());
            a.ab("ToolActionIconMenu", ToolActionIconMenuDescriptionMetadata.a);
        }
    }
    ToolActionIconMenuDescriptionMetadata.$t = /*@__PURE__*/ markType(ToolActionIconMenuDescriptionMetadata, 'ToolActionIconMenuDescriptionMetadata');
    ToolActionIconMenuDescriptionMetadata.a = null;
    return ToolActionIconMenuDescriptionMetadata;
})();
